Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func QueryStats ¶
func QueryStats(w http.ResponseWriter, r *http.Request)
QueryStats is a handler which just queries directly from the API for data
Types ¶
type Stats ¶
type Stats struct {
PoolHashrate int `json:"pool_hashrate"`
RoundHashes int64 `json:"round_hashes"`
NetworkHashrate int64 `json:"network_hashrate"`
NetworkDifficulty int64 `json:"network_difficulty"`
NetworkHeight int `json:"network_height"`
LastTemplateFetched int `json:"last_template_fetched"`
LastBlockFound int `json:"last_block_found"`
PoolBlocksFound int `json:"pool_blocks_found"`
PaymentThreshold float64 `json:"payment_threshold"`
PoolFee int `json:"pool_fee"`
PoolPort int `json:"pool_port"`
PoolSslPort int `json:"pool_ssl_port"`
AllowSelfSelect int `json:"allow_self_select"`
ConnectedMiners int `json:"connected_miners"`
MinerHashrate int `json:"miner_hashrate"`
MinerHashrateStats []int `json:"miner_hashrate_stats"`
MinerBalance float64 `json:"miner_balance"`
WorkerCount int `json:"worker_count"`
}
Stats is an autogenerated typed data from the API
Click to show internal directories.
Click to hide internal directories.